package com.chelvc.framework.upload.support;

import java.awt.image.BufferedImage;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import javax.imageio.ImageIO;

import com.chelvc.framework.base.util.FileUtils;
import com.chelvc.framework.base.util.HttpUtils;
import com.chelvc.framework.base.util.StringUtils;
import com.chelvc.framework.upload.UploadHandler;
import com.chelvc.framework.upload.config.StandardUploadProperties;
import lombok.NonNull;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.stereotype.Component;

/**
 * 文件上传标准实现
 *
 * @author Woody
 * @date 2023/5/6
 */
@Slf4j
@Component
@ConditionalOnBean(StandardUploadProperties.class)
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class StandardUploadHandler implements UploadHandler {
    private final StandardUploadProperties properties;

    @Override
    public String upload(@NonNull File file) {
        String suffix = FileUtils.getSuffix(file);
        String filename = StringUtils.uuid() + StringUtils.ifEmpty(suffix, "." + suffix);
        FileUtils.write(new File(this.properties.getPath(), filename), file);
        return HttpUtils.url(this.properties.getDomain(), filename);
    }

    @Override
    public String upload(@NonNull InputStream stream, @NonNull String suffix) {
        String filename = StringUtils.uuid() + StringUtils.ifEmpty(suffix, "." + suffix);
        FileUtils.write(new File(this.properties.getPath(), filename), stream);
        return HttpUtils.url(this.properties.getDomain(), filename);
    }

    @Override
    public String upload(@NonNull BufferedImage image) throws IOException {
        image = FileUtils.compress(image);
        String filename = StringUtils.uuid() + ".jpeg";
        try (FileOutputStream output = new FileOutputStream(new File(this.properties.getPath(), filename))) {
            ImageIO.write(image, "jpeg", output);
        }
        return HttpUtils.url(this.properties.getDomain(), filename);
    }
}
